@@ -11,11 +11,12 @@
 # under the License.
 
 import copy
+from unittest import mock
 
 from keystoneauth1 import exceptions as ksa_exceptions
-from keystoneauth1 import plugin as ksa_plugin
 from keystoneauth1 import session as ksa_session
-import mock
+
+from openstack.config import cloud_region
 
 from os_client_config import cloud_config
 from os_client_config import defaults
@@ -27,7 +28,6 @@ fake_config_dict = {'a': 1, 'os_b': 2, 'c': 3, 'os_c': 4}
 fake_services_dict = {
     'compute_api_version': '2',
     'compute_endpoint_override': 'http://compute.example.com',
-    'compute_region_name': 'region-bl',
     'telemetry_endpoint': 'http://telemetry.example.com',
     'interface': 'public',
     'image_service_type': 'mage',
@@ -46,14 +46,14 @@ class TestCloudConfig(base.TestCase):
         self.assertEqual("region-al", cc.region)
 
         # Look up straight value
-        self.assertEqual(1, cc.a)
+        self.assertEqual('1', cc.a)
 
         # Look up prefixed attribute, fail - returns None
         self.assertIsNone(cc.os_b)
 
         # Look up straight value, then prefixed value
-        self.assertEqual(3, cc.c)
-        self.assertEqual(3, cc.os_c)
+        self.assertEqual('3', cc.c)
+        self.assertEqual('3', cc.os_c)
 
         # Lookup mystery attribute
         self.assertIsNone(cc.x)
@@ -140,29 +140,19 @@ class TestCloudConfig(base.TestCase):
         self.assertEqual('admin', cc.get_interface('identity'))
         self.assertEqual('region-al', cc.get_region_name())
         self.assertEqual('region-al', cc.get_region_name('image'))
-        self.assertEqual('region-bl', cc.get_region_name('compute'))
         self.assertIsNone(cc.get_api_version('image'))
         self.assertEqual('2', cc.get_api_version('compute'))
         self.assertEqual('mage', cc.get_service_type('image'))
         self.assertEqual('compute', cc.get_service_type('compute'))
         self.assertEqual('1', cc.get_api_version('volume'))
-        self.assertEqual('volume', cc.get_service_type('volume'))
+        self.assertIn(
+            cc.get_service_type('volume'), ['block-storage', 'volume'])
         self.assertEqual('http://compute.example.com',
                          cc.get_endpoint('compute'))
         self.assertIsNone(cc.get_endpoint('image'))
         self.assertIsNone(cc.get_service_name('compute'))
         self.assertEqual('locks', cc.get_service_name('identity'))
 
-    def test_volume_override(self):
-        cc = cloud_config.CloudConfig("test1", "region-al", fake_services_dict)
-        cc.config['volume_api_version'] = '2'
-        self.assertEqual('volumev2', cc.get_service_type('volume'))
-
-    def test_volume_override_v3(self):
-        cc = cloud_config.CloudConfig("test1", "region-al", fake_services_dict)
-        cc.config['volume_api_version'] = '3'
-        self.assertEqual('volumev3', cc.get_service_type('volume'))
-
     def test_get_session_no_auth(self):
         config_dict = defaults.get_defaults()
         config_dict.update(fake_services_dict)
@@ -171,29 +161,6 @@ class TestCloudConfig(base.TestCase):
             exceptions.OpenStackConfigException,
             cc.get_session)
 
-    @mock.patch.object(ksa_session, 'Session')
-    def test_get_session(self, mock_session):
-        config_dict = defaults.get_defaults()
-        config_dict.update(fake_services_dict)
-        cc = cloud_config.CloudConfig(
-            "test1", "region-al", config_dict, auth_plugin=mock.Mock())
-        cc.get_session()
-        mock_session.assert_called_with(
-            auth=mock.ANY,
-            verify=True, cert=None, timeout=None)
-
-    @mock.patch.object(ksa_session, 'Session')
-    def test_get_session_with_timeout(self, mock_session):
-        config_dict = defaults.get_defaults()
-        config_dict.update(fake_services_dict)
-        config_dict['api_timeout'] = 9
-        cc = cloud_config.CloudConfig(
-            "test1", "region-al", config_dict, auth_plugin=mock.Mock())
-        cc.get_session()
-        mock_session.assert_called_with(
-            auth=mock.ANY,
-            verify=True, cert=None, timeout=9)
-
     @mock.patch.object(ksa_session, 'Session')
     def test_override_session_endpoint_override(self, mock_session):
         config_dict = defaults.get_defaults()
@@ -214,19 +181,7 @@ class TestCloudConfig(base.TestCase):
             cc.get_session_endpoint('telemetry'),
             fake_services_dict['telemetry_endpoint'])
 
-    @mock.patch.object(cloud_config.CloudConfig, 'get_session')
-    def test_session_endpoint_identity(self, mock_get_session):
-        mock_session = mock.Mock()
-        mock_get_session.return_value = mock_session
-        config_dict = defaults.get_defaults()
-        config_dict.update(fake_services_dict)
-        cc = cloud_config.CloudConfig(
-            "test1", "region-al", config_dict, auth_plugin=mock.Mock())
-        cc.get_session_endpoint('identity')
-        mock_session.get_endpoint.assert_called_with(
-            interface=ksa_plugin.AUTH_INTERFACE)
-
-    @mock.patch.object(cloud_config.CloudConfig, 'get_session')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_session')
     def test_session_endpoint(self, mock_get_session):
         mock_session = mock.Mock()
         mock_get_session.return_value = mock_session
@@ -241,7 +196,7 @@ class TestCloudConfig(base.TestCase):
             region_name='region-al',
             service_type='orchestration')
 
-    @mock.patch.object(cloud_config.CloudConfig, 'get_session')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_session')
     def test_session_endpoint_not_found(self, mock_get_session):
         exc_to_raise = ksa_exceptions.catalog.EndpointNotFound
         mock_get_session.return_value.get_endpoint.side_effect = exc_to_raise
@@ -249,9 +204,9 @@ class TestCloudConfig(base.TestCase):
             "test1", "region-al", {}, auth_plugin=mock.Mock())
         self.assertIsNone(cc.get_session_endpoint('notfound'))
 
-    @mock.patch.object(cloud_config.CloudConfig, 'get_api_version')
-    @mock.patch.object(cloud_config.CloudConfig, 'get_auth_args')
-    @mock.patch.object(cloud_config.CloudConfig, 'get_session_endpoint')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_api_version')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_auth_args')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_session_endpoint')
     def test_legacy_client_object_store_password(
             self,
             mock_get_session_endpoint,
@@ -280,8 +235,8 @@ class TestCloudConfig(base.TestCase):
                 'endpoint_type': 'public',
             })
 
-    @mock.patch.object(cloud_config.CloudConfig, 'get_auth_args')
-    @mock.patch.object(cloud_config.CloudConfig, 'get_session_endpoint')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_auth_args')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_session_endpoint')
     def test_legacy_client_object_store_password_v2(
             self, mock_get_session_endpoint, mock_get_auth_args):
         mock_client = mock.Mock()
@@ -306,8 +261,8 @@ class TestCloudConfig(base.TestCase):
                 'endpoint_type': 'public',
             })
 
-    @mock.patch.object(cloud_config.CloudConfig, 'get_auth_args')
-    @mock.patch.object(cloud_config.CloudConfig, 'get_session_endpoint')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_auth_args')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_session_endpoint')
     def test_legacy_client_object_store(
             self, mock_get_session_endpoint, mock_get_auth_args):
         mock_client = mock.Mock()
@@ -327,8 +282,8 @@ class TestCloudConfig(base.TestCase):
                 'endpoint_type': 'public',
             })
 
-    @mock.patch.object(cloud_config.CloudConfig, 'get_auth_args')
-    @mock.patch.object(cloud_config.CloudConfig, 'get_session_endpoint')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_auth_args')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_session_endpoint')
     def test_legacy_client_object_store_timeout(
             self, mock_get_session_endpoint, mock_get_auth_args):
         mock_client = mock.Mock()
@@ -338,7 +293,8 @@ class TestCloudConfig(base.TestCase):
         config_dict.update(fake_services_dict)
         config_dict['api_timeout'] = 9
         cc = cloud_config.CloudConfig(
-            "test1", "region-al", config_dict, auth_plugin=mock.Mock())
+            name="test1", region_name="region-al", config=config_dict,
+            auth_plugin=mock.Mock())
         cc.get_legacy_client('object-store', mock_client)
         mock_client.assert_called_with(
             session=mock.ANY,
@@ -349,7 +305,7 @@ class TestCloudConfig(base.TestCase):
                 'endpoint_type': 'public',
             })
 
-    @mock.patch.object(cloud_config.CloudConfig, 'get_auth_args')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_auth_args')
     def test_legacy_client_object_store_endpoint(
             self, mock_get_auth_args):
         mock_client = mock.Mock()
@@ -369,7 +325,7 @@ class TestCloudConfig(base.TestCase):
                 'endpoint_type': 'public',
             })
 
-    @mock.patch.object(cloud_config.CloudConfig, 'get_session_endpoint')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_session_endpoint')
     def test_legacy_client_image(self, mock_get_session_endpoint):
         mock_client = mock.Mock()
         mock_get_session_endpoint.return_value = 'http://example.com/v2'
@@ -389,7 +345,7 @@ class TestCloudConfig(base.TestCase):
             service_type='mage'
         )
 
-    @mock.patch.object(cloud_config.CloudConfig, 'get_session_endpoint')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_session_endpoint')
     def test_legacy_client_image_override(self, mock_get_session_endpoint):
         mock_client = mock.Mock()
         mock_get_session_endpoint.return_value = 'http://example.com/v2'
@@ -410,7 +366,7 @@ class TestCloudConfig(base.TestCase):
             service_type='mage'
         )
 
-    @mock.patch.object(cloud_config.CloudConfig, 'get_session_endpoint')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_session_endpoint')
     def test_legacy_client_image_versioned(self, mock_get_session_endpoint):
         mock_client = mock.Mock()
         mock_get_session_endpoint.return_value = 'http://example.com/v2'
@@ -432,7 +388,7 @@ class TestCloudConfig(base.TestCase):
             service_type='mage'
         )
 
-    @mock.patch.object(cloud_config.CloudConfig, 'get_session_endpoint')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_session_endpoint')
     def test_legacy_client_image_unversioned(self, mock_get_session_endpoint):
         mock_client = mock.Mock()
         mock_get_session_endpoint.return_value = 'http://example.com/'
@@ -454,7 +410,7 @@ class TestCloudConfig(base.TestCase):
             service_type='mage'
         )
 
-    @mock.patch.object(cloud_config.CloudConfig, 'get_session_endpoint')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_session_endpoint')
     def test_legacy_client_image_argument(self, mock_get_session_endpoint):
         mock_client = mock.Mock()
         mock_get_session_endpoint.return_value = 'http://example.com/v3'
@@ -476,7 +432,7 @@ class TestCloudConfig(base.TestCase):
             service_type='mage'
         )
 
-    @mock.patch.object(cloud_config.CloudConfig, 'get_session_endpoint')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_session_endpoint')
     def test_legacy_client_network(self, mock_get_session_endpoint):
         mock_client = mock.Mock()
         mock_get_session_endpoint.return_value = 'http://example.com/v2'
@@ -494,7 +450,7 @@ class TestCloudConfig(base.TestCase):
             session=mock.ANY,
             service_name=None)
 
-    @mock.patch.object(cloud_config.CloudConfig, 'get_session_endpoint')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_session_endpoint')
     def test_legacy_client_compute(self, mock_get_session_endpoint):
         mock_client = mock.Mock()
         mock_get_session_endpoint.return_value = 'http://example.com/v2'
@@ -512,7 +468,7 @@ class TestCloudConfig(base.TestCase):
             session=mock.ANY,
             service_name=None)
 
-    @mock.patch.object(cloud_config.CloudConfig, 'get_session_endpoint')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_session_endpoint')
     def test_legacy_client_identity(self, mock_get_session_endpoint):
         mock_client = mock.Mock()
         mock_get_session_endpoint.return_value = 'http://example.com/v2'
@@ -531,7 +487,7 @@ class TestCloudConfig(base.TestCase):
             session=mock.ANY,
             service_name='locks')
 
-    @mock.patch.object(cloud_config.CloudConfig, 'get_session_endpoint')
+    @mock.patch.object(cloud_region.CloudRegion, 'get_session_endpoint')
     def test_legacy_client_identity_v3(self, mock_get_session_endpoint):
         mock_client = mock.Mock()
         mock_get_session_endpoint.return_value = 'http://example.com'
@@ -544,7 +500,7 @@ class TestCloudConfig(base.TestCase):
         mock_client.assert_called_with(
             version='3',
             endpoint='http://example.com',
-            endpoint_type='admin',
+            interface='admin',
             endpoint_override=None,
             region_name='region-al',
             service_type='identity',
